=====
Usage
=====

To use WordStart in a project::

    >>>from wordstart.wordstart import wordstartfunc

	>>>stc = 'Print only the words that start with s in this sentence'
	>>>wordstartfunc(stc, 'W')
	words
	with